polimorfo package
=================

Subpackages
-----------

.. toctree::

    polimorfo.annotations
    polimorfo.datasets

Submodules
----------

polimorfo.cli module
--------------------

.. automodule:: polimorfo.cli
    :members:
    :undoc-members:
    :show-inheritance:

polimorfo.polimorfo module
--------------------------

.. automodule:: polimorfo.polimorfo
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: polimorfo
    :members:
    :undoc-members:
    :show-inheritance:
